@@ -1,3 +1,4 @@
+import operator
 import torch
 import copy
 import logging
@@ -363,6 +364,27 @@ def merge_list_of_lists(lists: List[list]):
     return merged
 
 
+def split_list_by_lengths(input_list: list, lengths: List[int]) -> List[list]:
+    """
+    Split a list into several lists given the lengths of each target list
+
+    Parameters
+    ----------
+    input_list: the list to split
+    lengths: the length of each target list
+
+    Returns
+    -------
+    a list of split lists
+    """
+    ends = list(itertools.accumulate(lengths, operator.add))
+    assert ends[-1] <= len(input_list), ValueError("The lengths does not match the input list!")
+
+    starts = [0] + ends[:-1]
+    output = [input_list[s:e] for s, e in zip(starts, ends)]
+    return output
+
+
 def sort_tuples_by_element_idx(tups: List[tuple],
                                idx: Optional[int] = 0,
                                reverse: Optional[bool] = False) -> List[tuple]:
